@@ -69,8 +69,8 @@ class PersonalModule(modules.LinkList):
         # Expose links
         self.pages_link = None
         self.pages_title = None
-        self.password_link = reverse('%s:password_change' % site_name)
-        self.logout_link = reverse('%s:logout' % site_name)
+        self.password_link = reverse('{0}:password_change'.format(site_name))
+        self.logout_link = reverse('{0}:logout'.format(site_name))
 
         if self.cms_page_model:
             try:
@@ -116,17 +116,16 @@ class AppIconList(modules.AppList):
         """
         super(AppIconList, self).init_with_context(context)
         apps = self.children
-        path_levels = context['request'].META['SCRIPT_NAME'].rstrip('/').count('/')
 
         # Standard model only has a title, change_url and add_url.
         # Restore the app_name and name, so icons can be matched.
         for app in apps:
-            app_name = app['url'].strip('/').split('/')[-1]   # /admin/appname/
+            app_name = app['url'].strip('/').split('/')[-1]   # /foo/admin/appname/
             app['name'] = app_name
 
             for model in app['models']:
                 try:
-                    model_name = model['change_url'].strip('/').split('/')[2 + path_levels]   # admin/appname/modelname
+                    model_name = model['change_url'].strip('/').split('/')[-1]   # /foo/admin/appname/modelname
                     model['name'] = model_name
                     model['icon'] = self.get_icon_for_model(app_name, model_name) or appsettings.FLUENT_DASHBOARD_DEFAULT_ICON
                 except ValueError:
@@ -142,7 +141,7 @@ class AppIconList(modules.AppList):
         Return the icon for the given model.
         It reads the :ref:`FLUENT_DASHBOARD_APP_ICONS` setting.
         """
-        key = "%s/%s" % (app_name, model_name)
+        key = "{0}/{1}".format(app_name, model_name)
         return appsettings.FLUENT_DASHBOARD_APP_ICONS.get(key, default)
 
 
